@@ -1,7 +1,7 @@
 ## tukeyTest.R
 ## Part of the R package: PMCMRplus
 ##
-## Copyright (C) 2017, 2018 Thorsten Pohlert
+## Copyright (C) 2017-2020 Thorsten Pohlert
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 ##  http://www.r-project.org/Licenses/
 
 #' @name tukeyTest
-#' @title Tukey's Test
+#' @title Tukey's Multiple Comparison Test
 #' @description
 #' Performs Tukey's all-pairs comparisons test for normally distributed
 #' data with equal group variances.
@@ -39,29 +39,27 @@
 #'
 #' Tukey, J. (1949) Comparing Individual Means in the Analysis of Variance,
 #' \emph{Biometrics} \bold{5}, 99--114.
-#' @concept AllPairsComparison
+#'
 #' @keywords htest
 #' @seealso
 #' \code{\link{Tukey}}, \code{\link{TukeyHSD}}
 #' @examples
-#' set.seed(245)
-#' mn <- rep(c(1, 2^(1:4)), each=5)
-#' sd <- rep(1, 25)
-#' x <- mn + rnorm(25, sd = sd)
-#' g <- factor(rep(1:5, each=5))
-#'
-#' fit <- aov(x ~ g)
+#' fit <- aov(weight ~ feed, chickwts)
 #' shapiro.test(residuals(fit))
-#' bartlett.test(x ~ g) # var1 = varN
+#' bartlett.test(weight ~ feed, chickwts)
 #' anova(fit)
-#' summary(tukeyTest(x, g))
+#'
+#' ## also works with fitted objects of class aov
+#' res <- tukeyTest(fit)
+#' summary(res)
+#' summaryGroup(res)
 #' @export
 tukeyTest <- function(x, ...) UseMethod("tukeyTest")
 
 #' @rdname tukeyTest
 #' @aliases tukeyTest.default
 #' @method tukeyTest default
-#' @template one-way-parms
+#' @template one-way-parms-aov
 #' @importFrom stats complete.cases
 #' @importFrom stats var
 #' @importFrom stats ptukey
@@ -147,3 +145,17 @@ function(formula, data, subset, na.action, ...)
     y$data.name <- DNAME
     y
 }
+
+#' @rdname tukeyTest
+#' @aliases tukeyTest.aov
+#' @method tukeyTest aov
+# @param obj A fitted model object, usually an \link[stats]{aov} fit.
+#' @export
+tukeyTest.aov <- function(x, ...) {
+  model <- x$model
+  DNAME <- paste(names(model), collapse = " by ")
+  names(model) <- c("x", "g")
+  y <- do.call("tukeyTest", as.list(model))
+  y$data.name <- DNAME
+  y
+}
